@@ -784,8 +784,8 @@ class QuestionAnsweringHead(PredictionHead):
         pos_answer_dedup = self.deduplicate(pos_answers_flat)
 
         # This is how much no_ans_boost needs to change to turn a no_answer to a positive answer (or vice versa)
-        no_ans_gap = -min([nas - pbs for nas, pbs in zip(no_answer_scores, passage_best_score)])
-        no_ans_gap_confidence = -min([nas - pbs for nas, pbs in zip(no_answer_confidences, passage_best_confidence)])
+        no_ans_gap = -min(nas - pbs for nas, pbs in zip(no_answer_scores, passage_best_score))
+        no_ans_gap_confidence = -min(nas - pbs for nas, pbs in zip(no_answer_confidences, passage_best_confidence))
 
         # "no answer" scores and positive answers scores are difficult to compare, because
         # + a positive answer score is related to a specific text qa_candidate
