@@ -44,6 +44,8 @@ from transformers import (
     DPRQuestionEncoderTokenizerFast,
     BigBirdTokenizer,
     BigBirdTokenizerFast,
+    DebertaV2Tokenizer,
+    DebertaV2TokenizerFast,
 )
 from transformers import AutoConfig
 
@@ -197,6 +199,15 @@ class Tokenizer:
                 ret = BigBirdTokenizer.from_pretrained(
                     pretrained_model_name_or_path, use_auth_token=use_auth_token, **kwargs
                 )
+        elif "DebertaV2Tokenizer" in tokenizer_class:
+            if use_fast:
+                ret = DebertaV2TokenizerFast.from_pretrained(
+                    pretrained_model_name_or_path, use_auth_token=use_auth_token, **kwargs
+                )
+            else:
+                ret = DebertaV2Tokenizer.from_pretrained(
+                    pretrained_model_name_or_path, use_auth_token=use_auth_token, **kwargs
+                )
         if ret is None:
             raise Exception("Unable to load tokenizer")
         return ret
@@ -246,10 +257,12 @@ class Tokenizer:
                 raise NotImplementedError("DPRReader models are currently not supported.")
         elif model_type == "big_bird":
             tokenizer_class = "BigBirdTokenizer"
+        elif model_type == "deberta-v2":
+            tokenizer_class = "DebertaV2Tokenizer"
         else:
             # Fall back to inferring type from model name
             logger.warning(
-                "Could not infer Tokenizer type from config. Trying to infer " "Tokenizer type from model name."
+                "Could not infer Tokenizer type from config. Trying to infer Tokenizer type from model name."
             )
             tokenizer_class = Tokenizer._infer_tokenizer_class_from_string(pretrained_model_name_or_path)
 
@@ -275,6 +288,10 @@ class Tokenizer:
             tokenizer_class = "CamembertTokenizer"
         elif "distilbert" in pretrained_model_name_or_path.lower():
             tokenizer_class = "DistilBertTokenizer"
+        elif (
+            "debertav2" in pretrained_model_name_or_path.lower() or "debertav3" in pretrained_model_name_or_path.lower()
+        ):
+            tokenizer_class = "DebertaV2Tokenizer"
         elif "bert" in pretrained_model_name_or_path.lower():
             tokenizer_class = "BertTokenizer"
         elif "xlnet" in pretrained_model_name_or_path.lower():
