@@ -1,5 +1,5 @@
 from __future__ import annotations
-from typing import Any, Optional, Dict, List, Tuple, Type
+from typing import Any, Optional, Dict, List, Tuple, Union, Callable, Type
 
 from copy import deepcopy
 from abc import ABC, abstractmethod
@@ -10,6 +10,7 @@ import logging
 from haystack.schema import Document, MultiLabel
 from haystack.errors import PipelineSchemaError
 from haystack.telemetry import send_custom_event
+from haystack.utils import args_to_kwargs
 
 
 logger = logging.getLogger(__name__)
@@ -37,18 +38,12 @@ def exportable_to_yaml(init_func):
         #   Inner classes are heavily used in tests.
         if init_func.__qualname__.endswith(f"{self.__class__.__name__}.{init_func.__name__}"):
 
-            # Store all the named input parameters in self._component_config
-            for k, v in kwargs.items():
+            # Store all the input parameters in self._component_config
+            args_as_kwargs = args_to_kwargs(args, init_func)
+            params = {**args_as_kwargs, **kwargs}
+            for k, v in params.items():
                 self._component_config["params"][k] = v
 
-            # Store unnamed input parameters in self._component_config too by inferring their names
-            sig = inspect.signature(init_func)
-            parameter_names = list(sig.parameters.keys())
-            # we can be sure that the first one is always "self"
-            arg_names = parameter_names[1 : 1 + len(args)]
-            for arg, arg_name in zip(args, arg_names):
-                self._component_config["params"][arg_name] = arg
-
     return wrapper_exportable_to_yaml
 
 
@@ -119,15 +114,17 @@ class BaseComponent(ABC):
         return subclass
 
     @classmethod
-    def _create_instance(cls, component_type: str, component_params: Dict[str, Any]):
+    def _create_instance(cls, component_type: str, component_params: Dict[str, Any], name: Optional[str] = None):
         """
         Returns an instance of the given subclass of BaseComponent.
 
         :param component_type: name of the component class to load.
         :param component_params: parameters to pass to the __init__() for the component.
+        :param name: name of the component instance
         """
         subclass = cls.get_subclass(component_type)
         instance = subclass(**component_params)
+        instance.name = name
         return instance
 
     @abstractmethod
@@ -151,27 +148,51 @@ class BaseComponent(ABC):
         """
         pass
 
+    @abstractmethod
+    def run_batch(
+        self,
+        queries: Optional[Union[str, List[str]]] = None,
+        file_paths: Optional[List[str]] = None,
+        labels: Optional[Union[MultiLabel, List[MultiLabel]]] = None,
+        documents: Optional[Union[List[Document], List[List[Document]]]] = None,
+        meta: Optional[Union[Dict[str, Any], List[Dict[str, Any]]]] = None,
+        params: Optional[dict] = None,
+        debug: Optional[bool] = None,
+    ):
+        pass
+
     def _dispatch_run(self, **kwargs) -> Tuple[Dict, str]:
         """
-        The Pipelines call this method which in turn executes the run() method of Component.
+        The Pipelines call this method when run() is executed. This method in turn executes the _dispatch_run_general()
+        method with the correct run method.
+        """
+        return self._dispatch_run_general(self.run, **kwargs)
 
-        It takes care of the following:
-          - inspect run() signature to validate if all necessary arguments are available
+    def _dispatch_run_batch(self, **kwargs):
+        """
+        The Pipelines call this method when run_batch() is executed. This method in turn executes the
+        _dispatch_run_general() method with the correct run method.
+        """
+        return self._dispatch_run_general(self.run_batch, **kwargs)
+
+    def _dispatch_run_general(self, run_method: Callable, **kwargs):
+        """
+        This method takes care of the following:
+          - inspect run_method's signature to validate if all necessary arguments are available
           - pop `debug` and sets them on the instance to control debug output
-          - call run() with the corresponding arguments and gather output
+          - call run_method with the corresponding arguments and gather output
           - collate `_debug` information if present
           - merge component output with the preceding output and pass it on to the subsequent Component in the Pipeline
         """
         arguments = deepcopy(kwargs)
         params = arguments.get("params") or {}
 
-        run_signature_args = inspect.signature(self.run).parameters.keys()
+        run_signature_args = inspect.signature(run_method).parameters.keys()
 
         run_params: Dict[str, Any] = {}
         for key, value in params.items():
             if key == self.name:  # targeted params for this node
                 if isinstance(value, dict):
-
                     # Extract debug attributes
                     if "debug" in value.keys():
                         self.debug = value.pop("debug")
@@ -189,7 +210,7 @@ class BaseComponent(ABC):
             if key in run_signature_args:
                 run_inputs[key] = value
 
-        output, stream = self.run(**run_inputs, **run_params)
+        output, stream = run_method(**run_inputs, **run_params)
 
         # Collect debug information
         debug_info = {}
@@ -197,10 +218,8 @@ class BaseComponent(ABC):
             # Include input
             debug_info["input"] = {**run_inputs, **run_params}
             debug_info["input"]["debug"] = self.debug
-            # Include output
-            filtered_output = {
-                key: value for key, value in output.items() if key != "_debug"
-            }  # Exclude _debug to avoid recursion
+            # Include output, exclude _debug to avoid recursion
+            filtered_output = {key: value for key, value in output.items() if key != "_debug"}
             debug_info["output"] = filtered_output
         # Include custom debug info
         custom_debug = output.get("_debug", {})
@@ -242,3 +261,6 @@ class RootNode(BaseComponent):
 
     def run(self):  # type: ignore
         return {}, "output_1"
+
+    def run_batch(self):  # type: ignore
+        return {}, "output_1"
