@@ -1,4 +1,5 @@
-from typing import List, Optional, Set
+import itertools
+from typing import List, Optional, Set, Union
 
 import logging
 from transformers import pipeline
@@ -60,6 +61,7 @@ class TransformersSummarizer(BaseSummarizer):
         clean_up_tokenization_spaces: bool = True,
         separator_for_single_summary: str = " ",
         generate_single_summary: bool = False,
+        batch_size: Optional[int] = None,
     ):
         """
         Load a Summarization model from Transformers.
@@ -81,6 +83,7 @@ class TransformersSummarizer(BaseSummarizer):
                                         If set to "True", all docs will be joined to a single string that will then
                                         be summarized.
                                         Important: The summary will depend on the order of the supplied documents!
+        :param batch_size: Number of documents to process at a time.
         """
         super().__init__()
 
@@ -99,10 +102,9 @@ class TransformersSummarizer(BaseSummarizer):
         self.separator_for_single_summary = separator_for_single_summary
         self.generate_single_summary = generate_single_summary
         self.print_log: Set[str] = set()
+        self.batch_size = batch_size
 
-    def predict(
-        self, documents: List[Document], generate_single_summary: Optional[bool] = None, truncation: bool = True
-    ) -> List[Document]:
+    def predict(self, documents: List[Document], generate_single_summary: Optional[bool] = None) -> List[Document]:
         """
         Produce the summarization from the supplied documents.
         These document can for example be retrieved via the Retriever.
@@ -112,7 +114,6 @@ class TransformersSummarizer(BaseSummarizer):
                                         If set to "True", all docs will be joined to a single string that will then
                                         be summarized.
                                         Important: The summary will depend on the order of the supplied documents!
-        :param truncation: Truncate to a maximum length accepted by the model
         :return: List of Documents, where Document.text contains the summarization and Document.meta["context"]
                  the original, not summarized text
         """
@@ -162,3 +163,110 @@ class TransformersSummarizer(BaseSummarizer):
             result.append(cur_doc)
 
         return result
+
+    def predict_batch(
+        self,
+        documents: Union[List[Document], List[List[Document]]],
+        generate_single_summary: Optional[bool] = None,
+        batch_size: Optional[int] = None,
+    ) -> Union[List[Document], List[List[Document]]]:
+        """
+        Produce the summarization from the supplied documents.
+        These documents can for example be retrieved via the Retriever.
+
+        :param documents: Single list of related documents or list of lists of related documents
+                          (e.g. coming from a retriever) that the answer shall be conditioned on.
+        :param generate_single_summary: Whether to generate a single summary for each provided document list or
+                                        one summary per document.
+                                        If set to "True", all docs of a document list will be joined to a single string
+                                        that will then be summarized.
+                                        Important: The summary will depend on the order of the supplied documents!
+        :param batch_size: Number of Documents to process at a time.
+        """
+
+        if self.min_length > self.max_length:
+            raise AttributeError("min_length cannot be greater than max_length")
+
+        if len(documents) == 0 or (
+            isinstance(documents[0], list) and all(len(docs) == 0 for docs in documents if isinstance(docs, list))
+        ):
+            raise AttributeError("Summarizer needs at least one document to produce a summary.")
+
+        if batch_size is None:
+            batch_size = self.batch_size
+
+        if generate_single_summary is None:
+            generate_single_summary = self.generate_single_summary
+
+        single_doc_list = False
+        if isinstance(documents[0], Document):
+            single_doc_list = True
+
+        if single_doc_list:
+            contexts = [doc.content for doc in documents if isinstance(doc, Document)]
+        else:
+            contexts = [
+                [doc.content for doc in docs if isinstance(doc, Document)]
+                for docs in documents
+                if isinstance(docs, list)
+            ]
+
+        if generate_single_summary:
+            if single_doc_list:
+                contexts = [self.separator_for_single_summary.join(contexts)]
+            else:
+                contexts = [self.separator_for_single_summary.join(context_group) for context_group in contexts]
+            number_of_docs = [1 for _ in contexts]
+        else:
+            if single_doc_list:
+                number_of_docs = [1 for _ in contexts]
+            else:
+                number_of_docs = [len(context_group) for context_group in contexts]
+                contexts = list(itertools.chain.from_iterable(contexts))
+
+        encoded_input = self.summarizer.tokenizer(contexts, verbose=False)
+        for input_id in encoded_input["input_ids"]:
+            tokens_count: int = len(input_id)
+            if tokens_count > self.summarizer.tokenizer.model_max_length:
+                truncation_warning = (
+                    "One or more of your input document texts is longer than the specified "
+                    f"maximum sequence length for this summarizer model. "
+                    f"Generating summary from first {self.summarizer.tokenizer.model_max_length}"
+                    f" tokens."
+                )
+                logger.warning(truncation_warning)
+                break
+
+        summaries = self.summarizer(
+            contexts,
+            min_length=self.min_length,
+            max_length=self.max_length,
+            return_text=True,
+            clean_up_tokenization_spaces=self.clean_up_tokenization_spaces,
+            truncation=True,
+            batch_size=batch_size,
+        )
+
+        # Group summaries together
+        grouped_summaries = []
+        grouped_contexts = []
+        left_idx = 0
+        right_idx = 0
+        for number in number_of_docs:
+            right_idx = left_idx + number
+            grouped_summaries.append(summaries[left_idx:right_idx])
+            grouped_contexts.append(contexts[left_idx:right_idx])
+            left_idx = right_idx
+
+        result = []
+        for summary_group, context_group in zip(grouped_summaries, grouped_contexts):
+            cur_summaries = [
+                Document(content=summary["summary_text"], meta={"context": context})
+                for summary, context in zip(summary_group, context_group)
+            ]
+            if single_doc_list:
+                result.append(cur_summaries[0])
+            else:
+                result.append(cur_summaries)  # type: ignore
+
+        return result
