@@ -2,10 +2,10 @@ from typing import Any, Dict, List, Optional
 
 import re
 import os
-import copy
 import json
 import logging
 from pathlib import Path
+from copy import copy
 
 import yaml
 import networkx as nx
@@ -67,13 +67,22 @@ def get_component_definitions(
                                          `_` sign must be used to specify nested hierarchical properties.
     """
     component_definitions = {}  # definitions of each component from the YAML.
-    raw_component_definitions = copy.deepcopy(pipeline_config["components"])
-    for component_definition in raw_component_definitions:
-        if overwrite_with_env_variables:
-            _overwrite_with_env_variables(component_definition)
-        name = component_definition.pop("name")
+
+    for raw_component_definition in pipeline_config["components"]:
+        name = raw_component_definition["name"]
+        # We perform a shallow copy here because of https://github.com/deepset-ai/haystack/issues/2568
+        component_definition = {key: copy(value) for key, value in raw_component_definition.items() if key != "name"}
         component_definitions[name] = component_definition
 
+        if overwrite_with_env_variables:
+            for key, value in os.environ.items():
+                env_prefix = f"{name}_params_".upper()
+                if key.startswith(env_prefix):
+                    param_name = key.replace(env_prefix, "").lower()
+                    component_definition["params"][param_name] = value
+                    logger.info(
+                        f"Param '{param_name}' of component '{name}' overwritten with environment variable '{key}' value '{value}'."
+                    )
     return component_definitions
 
 
@@ -489,21 +498,3 @@ def _get_defined_node_class(node_name: str, components: Dict[str, Dict[str, str]
         ) from e
 
     return node_class
-
-
-def _overwrite_with_env_variables(component_definition: Dict[str, Any]):
-    """
-    Overwrite the pipeline config with environment variables. For example, to change index name param for an
-    ElasticsearchDocumentStore, an env variable 'MYDOCSTORE_PARAMS_INDEX=documents-2021' can be set. Note that an
-    `_` sign must be used to specify nested hierarchical properties.
-
-    :param definition: a dictionary containing the YAML definition of a component.
-    """
-    env_prefix = f"{component_definition['name']}_params_".upper()
-    for key, value in os.environ.items():
-        if key.startswith(env_prefix):
-            param_name = key.replace(env_prefix, "").lower()
-            component_definition["params"][param_name] = value
-            logger.info(
-                f"Param '{param_name}' of component '{component_definition['name']}' overwritten with environment variable '{key}' value '{value}'."
-            )
