@@ -2,8 +2,13 @@ import logging
 from abc import ABC
 from copy import deepcopy
 from pathlib import Path
-from typing import List, Optional, Dict, Any
 from functools import wraps
+from typing import List, Optional, Dict, Any, Union
+
+try:
+    from typing import Literal
+except ImportError:
+    from typing_extensions import Literal  # type: ignore
 
 from haystack.schema import Document, EvaluationResult, MultiLabel
 from haystack.nodes.answer_generator.base import BaseGenerator
@@ -158,25 +163,57 @@ class BaseStandardPipeline(ABC):
         labels: List[MultiLabel],
         params: Optional[dict] = None,
         sas_model_name_or_path: Optional[str] = None,
+        sas_batch_size: int = 32,
+        sas_use_gpu: bool = True,
         add_isolated_node_eval: bool = False,
+        custom_document_id_field: Optional[str] = None,
+        context_matching_min_length: int = 100,
+        context_matching_boost_split_overlaps: bool = True,
+        context_matching_threshold: float = 65.0,
     ) -> EvaluationResult:
 
         """
         Evaluates the pipeline by running the pipeline once per query in debug mode
         and putting together all data that is needed for evaluation, e.g. calculating metrics.
 
+        If you want to calculate SAS (Semantic Answer Similarity) metrics, you have to specify `sas_model_name_or_path`.
+
+        You will be able to control the scope within which an answer or a document is considered correct afterwards (See `document_scope` and `answer_scope` params in `EvaluationResult.calculate_metrics()`).
+        Some of these scopes require additional information that already needs to be specified during `eval()`:
+        - `custom_document_id_field` param to select a custom document ID from document's meta data for ID matching (only affects 'document_id' scopes)
+        - `context_matching_...` param to fine-tune the fuzzy matching mechanism that determines whether some text contexts match each other (only affects 'context' scopes, default values should work most of the time)
+
         :param labels: The labels to evaluate on
         :param params: Params for the `retriever` and `reader`. For instance,
                        params={"Retriever": {"top_k": 10}, "Reader": {"top_k": 5}}
         :param sas_model_name_or_path: SentenceTransformers semantic textual similarity model to be used for sas value calculation,
                                     should be path or string pointing to downloadable models.
+        :param sas_batch_size: Number of prediction label pairs to encode at once by CrossEncoder or SentenceTransformer while calculating SAS.
+        :param sas_use_gpu: Whether to use a GPU or the CPU for calculating semantic answer similarity.
+                            Falls back to CPU if no GPU is available.
         :param add_isolated_node_eval: Whether to additionally evaluate the reader based on labels as input instead of output of previous node in pipeline
+        :param custom_document_id_field: Custom field name within `Document`'s `meta` which identifies the document and is being used as criterion for matching documents to labels during evaluation.
+                                         This is especially useful if you want to match documents on other criteria (e.g. file names) than the default document ids as these could be heavily influenced by preprocessing.
+                                         If not set (default) the `Document`'s `id` is being used as criterion for matching documents to labels.
+        :param context_matching_min_length: The minimum string length context and candidate need to have in order to be scored.
+                           Returns 0.0 otherwise.
+        :param context_matching_boost_split_overlaps: Whether to boost split overlaps (e.g. [AB] <-> [BC]) that result from different preprocessing params.
+                                 If we detect that the score is near a half match and the matching part of the candidate is at its boundaries
+                                 we cut the context on the same side, recalculate the score and take the mean of both.
+                                 Thus [AB] <-> [BC] (score ~50) gets recalculated with B <-> B (score ~100) scoring ~75 in total.
+        :param context_matching_threshold: Score threshold that candidates must surpass to be included into the result list. Range: [0,100]
         """
         output = self.pipeline.eval(
             labels=labels,
             params=params,
             sas_model_name_or_path=sas_model_name_or_path,
+            sas_batch_size=sas_batch_size,
+            sas_use_gpu=sas_use_gpu,
             add_isolated_node_eval=add_isolated_node_eval,
+            custom_document_id_field=custom_document_id_field,
+            context_matching_boost_split_overlaps=context_matching_boost_split_overlaps,
+            context_matching_min_length=context_matching_min_length,
+            context_matching_threshold=context_matching_threshold,
         )
         return output
 
@@ -185,13 +222,76 @@ class BaseStandardPipeline(ABC):
         eval_result: EvaluationResult,
         n_wrong_examples: int = 3,
         metrics_filter: Optional[Dict[str, List[str]]] = None,
+        document_scope: Literal[
+            "document_id",
+            "context",
+            "document_id_and_context",
+            "document_id_or_context",
+            "answer",
+            "document_id_or_answer",
+        ] = "document_id_or_answer",
+        answer_scope: Literal["any", "context", "document_id", "document_id_and_context"] = "any",
     ):
+        """
+        Prints evaluation report containing a metrics funnel and worst queries for further analysis.
+
+        :param eval_result: The evaluation result, can be obtained by running eval().
+        :param n_wrong_examples: The number of worst queries to show.
+        :param metrics_filter: The metrics to show per node. If None all metrics will be shown.
+        :param document_scope: A criterion for deciding whether documents are relevant or not.
+            You can select between:
+            - 'document_id': Specifies that the document ID must match. You can specify a custom document ID through `pipeline.eval()`'s `custom_document_id_field` param.
+                    A typical use case is Document Retrieval.
+            - 'context': Specifies that the content of the document must match. Uses fuzzy matching (see `pipeline.eval()`'s `context_matching_...` params).
+                    A typical use case is Document-Independent Passage Retrieval.
+            - 'document_id_and_context': A Boolean operation specifying that both `'document_id' AND 'context'` must match.
+                    A typical use case is Document-Specific Passage Retrieval.
+            - 'document_id_or_context': A Boolean operation specifying that either `'document_id' OR 'context'` must match.
+                    A typical use case is Document Retrieval having sparse context labels.
+            - 'answer': Specifies that the document contents must include the answer. The selected `answer_scope` is enforced automatically.
+                    A typical use case is Question Answering.
+            - 'document_id_or_answer' (default): A Boolean operation specifying that either `'document_id' OR 'answer'` must match.
+                    This is intended to be a proper default value in order to support both main use cases:
+                    - Document Retrieval
+                    - Question Answering
+            The default value is 'document_id_or_answer'.
+        :param answer_scope: Specifies the scope in which a matching answer is considered correct.
+            You can select between:
+            - 'any' (default): Any matching answer is considered correct.
+            - 'context': The answer is only considered correct if its context matches as well.
+                    Uses fuzzy matching (see `pipeline.eval()`'s `context_matching_...` params).
+            - 'document_id': The answer is only considered correct if its document ID matches as well.
+                    You can specify a custom document ID through `pipeline.eval()`'s `custom_document_id_field` param.
+            - 'document_id_and_context': The answer is only considered correct if its document ID and its context match as well.
+            The default value is 'any'.
+            In Question Answering, to enforce that the retrieved document is considered correct whenever the answer is correct, set `document_scope` to 'answer' or 'document_id_or_answer'.
+        """
         if metrics_filter is None:
             metrics_filter = self.metrics_filter
         self.pipeline.print_eval_report(
-            eval_result=eval_result, n_wrong_examples=n_wrong_examples, metrics_filter=metrics_filter
+            eval_result=eval_result,
+            n_wrong_examples=n_wrong_examples,
+            metrics_filter=metrics_filter,
+            document_scope=document_scope,
+            answer_scope=answer_scope,
         )
 
+    def run_batch(self, queries: List[str], params: Optional[dict] = None, debug: Optional[bool] = None):
+        """
+        Run a batch of queries through the pipeline.
+
+        :param queries: List of query strings.
+        :param params: Parameters for the individual nodes of the pipeline. For instance,
+                       `params={"Retriever": {"top_k": 10}, "Reader": {"top_k": 5}}`
+        :param debug: Whether the pipeline should instruct nodes to collect debug information
+                      about their execution. By default these include the input parameters
+                      they received and the output they generated.
+                      All debug information can then be found in the dict returned
+                      by this method under the key "_debug"
+        """
+        output = self.pipeline.run_batch(queries=queries, params=params, debug=debug)
+        return output
+
 
 class ExtractiveQAPipeline(BaseStandardPipeline):
     """
@@ -330,6 +430,45 @@ class SearchSummarizationPipeline(BaseStandardPipeline):
             results = output
         return results
 
+    def run_batch(self, queries: List[str], params: Optional[dict] = None, debug: Optional[bool] = None):
+        """
+        Run a batch of queries through the pipeline.
+
+        :param queries: List of query strings.
+        :param params: Parameters for the individual nodes of the pipeline. For instance,
+                       `params={"Retriever": {"top_k": 10}, "Summarizer": {"generate_single_summary": True}}`
+        :param debug: Whether the pipeline should instruct nodes to collect debug information
+                      about their execution. By default these include the input parameters
+                      they received and the output they generated.
+                      All debug information can then be found in the dict returned
+                      by this method under the key "_debug"
+        """
+        output = self.pipeline.run_batch(queries=queries, params=params, debug=debug)
+
+        # Convert to answer format to allow "drop-in replacement" for other QA pipelines
+        if self.return_in_answer_format:
+            results: Dict = {"queries": queries, "answers": []}
+            docs = deepcopy(output["documents"])
+            for query, cur_docs in zip(queries, docs):
+                cur_answers = []
+                for doc in cur_docs:
+                    cur_answer = {
+                        "query": query,
+                        "answer": doc.content,
+                        "document_id": doc.id,
+                        "context": doc.meta.pop("context"),
+                        "score": None,
+                        "offset_start": None,
+                        "offset_end": None,
+                        "meta": doc.meta,
+                    }
+                    cur_answers.append(cur_answer)
+
+                results["answers"].append(cur_answers)
+        else:
+            results = output
+        return results
+
 
 class FAQPipeline(BaseStandardPipeline):
     """
@@ -399,6 +538,10 @@ class TranslationWrapperPipeline(BaseStandardPipeline):
         output = self.pipeline.run(**kwargs)
         return output
 
+    def run_batch(self, **kwargs):
+        output = self.pipeline.run_batch(**kwargs)
+        return output
+
 
 class QuestionGenerationPipeline(BaseStandardPipeline):
     """
@@ -414,6 +557,15 @@ class QuestionGenerationPipeline(BaseStandardPipeline):
         output = self.pipeline.run(documents=documents, params=params, debug=debug)
         return output
 
+    def run_batch(  # type: ignore
+        self,
+        documents: Union[List[Document], List[List[Document]]],
+        params: Optional[dict] = None,
+        debug: Optional[bool] = None,
+    ):
+        output = self.pipeline.run_batch(documents=documents, params=params, debug=debug)
+        return output
+
 
 class RetrieverQuestionGenerationPipeline(BaseStandardPipeline):
     """
@@ -450,12 +602,13 @@ class QuestionAnswerGenerationPipeline(BaseStandardPipeline):
         @wraps(fn)
         def wrapper(*args, **kwargs):
             output, output_stream = fn(*args, **kwargs)
-            questions = output["generated_questions"][0]["questions"]
-            documents = output["documents"]
-            query_doc_list = []
-            for q in questions:
-                query_doc_list.append({"queries": q, "docs": documents})
-            kwargs["query_doc_list"] = query_doc_list
+            questions = []
+            documents = []
+            for generated_questions, doc in zip(output["generated_questions"], output["documents"]):
+                questions.extend(generated_questions["questions"])
+                documents.extend([[doc]] * len(generated_questions["questions"]))
+            kwargs["queries"] = questions
+            kwargs["documents"] = documents
             return kwargs, output_stream
 
         return wrapper
@@ -494,3 +647,10 @@ class MostSimilarDocumentsPipeline(BaseStandardPipeline):
 
         self.document_store.return_embedding = False  # type: ignore
         return similar_documents
+
+    def run_batch(self, document_ids: List[str], top_k: int = 5):  # type: ignore
+        """
+        :param document_ids: document ids
+        :param top_k: How many documents id to return against single document
+        """
+        return self.run(document_ids=document_ids, top_k=top_k)
