@@ -1,5 +1,10 @@
 from typing import Any, Dict, List, Optional
 
+try:
+    from typing import Literal
+except ImportError:
+    from typing_extensions import Literal  # type: ignore
+
 import re
 import sys
 import inspect
@@ -74,6 +79,7 @@ def generate_code(
         component_definitions=component_definitions,
         component_variable_names=component_variable_names,
         dependency_graph=component_dependency_graph,
+        pipeline_definition=pipeline_definition,
     )
     pipeline_code = _generate_pipeline_code(
         pipeline_definition=pipeline_definition,
@@ -109,7 +115,10 @@ def _generate_pipeline_code(
 
 
 def _generate_components_code(
-    component_definitions: Dict[str, Any], component_variable_names: Dict[str, str], dependency_graph: DiGraph
+    component_definitions: Dict[str, Any],
+    component_variable_names: Dict[str, str],
+    dependency_graph: DiGraph,
+    pipeline_definition: Dict[str, Any],
 ) -> str:
     code = ""
     declarations = {}
@@ -121,7 +130,11 @@ def _generate_components_code(
             for key, value in definition.get("params", {}).items()
         }
         init_args = ", ".join(f"{key}={value}" for key, value in param_value_dict.items())
-        declarations[name] = f"{variable_name} = {class_name}({init_args})"
+        declaration = f"{variable_name} = {class_name}({init_args})"
+        # set name of subcomponents explicitly if it's not the default name as it won't be set via Pipeline.add_node()
+        if name != class_name and name not in (node["name"] for node in pipeline_definition["nodes"]):
+            declaration = f'{declaration}\n{variable_name}.name = "{name}"'
+        declarations[name] = declaration
 
     ordered_components = nx.topological_sort(dependency_graph)
     ordered_declarations = [declarations[component] for component in ordered_components]
@@ -161,7 +174,10 @@ def print_eval_report(
     graph: DiGraph,
     n_wrong_examples: int = 3,
     metrics_filter: Optional[Dict[str, List[str]]] = None,
-    doc_relevance_col: str = "gold_id_or_answer_match",
+    document_scope: Literal[
+        "document_id", "context", "document_id_and_context", "document_id_or_context", "answer", "document_id_or_answer"
+    ] = "document_id_or_answer",
+    answer_scope: Literal["any", "context", "document_id", "document_id_and_context"] = "any",
 ):
     """
     Prints a report for a given EvaluationResult visualizing metrics per node specified by the pipeline graph.
@@ -171,18 +187,50 @@ def print_eval_report(
     :param n_wrong_examples: The number of examples to show in order to inspect wrong predictions.
                              Defaults to 3.
     :param metrics_filter: Specifies which metrics of eval_result to show in the report.
-    :param doc_relevance_col: column in the underlying eval table that contains the relevance criteria for documents.
-            Values can be: 'gold_id_match', 'answer_match', 'gold_id_or_answer_match'.
-            Default value is 'gold_id_or_answer_match'.
+        :param document_scope: A criterion for deciding whether documents are relevant or not.
+            You can select between:
+            - 'document_id': Specifies that the document ID must match. You can specify a custom document ID through `pipeline.eval()`'s `custom_document_id_field` param.
+                    A typical use case is Document Retrieval.
+            - 'context': Specifies that the content of the document must match. Uses fuzzy matching (see `pipeline.eval()`'s `context_matching_...` params).
+                    A typical use case is Document-Independent Passage Retrieval.
+            - 'document_id_and_context': A Boolean operation specifying that both `'document_id' AND 'context'` must match.
+                    A typical use case is Document-Specific Passage Retrieval.
+            - 'document_id_or_context': A Boolean operation specifying that either `'document_id' OR 'context'` must match.
+                    A typical use case is Document Retrieval having sparse context labels.
+            - 'answer': Specifies that the document contents must include the answer. The selected `answer_scope` is enforced automatically.
+                    A typical use case is Question Answering.
+            - 'document_id_or_answer' (default): A Boolean operation specifying that either `'document_id' OR 'answer'` must match.
+                    This is intended to be a proper default value in order to support both main use cases:
+                    - Document Retrieval
+                    - Question Answering
+            The default value is 'document_id_or_answer'.
+        :param answer_scope: Specifies the scope in which a matching answer is considered correct.
+            You can select between:
+            - 'any' (default): Any matching answer is considered correct.
+            - 'context': The answer is only considered correct if its context matches as well.
+                    Uses fuzzy matching (see `pipeline.eval()`'s `context_matching_...` params).
+            - 'document_id': The answer is only considered correct if its document ID matches as well.
+                    You can specify a custom document ID through `pipeline.eval()`'s `custom_document_id_field` param.
+            - 'document_id_and_context': The answer is only considered correct if its document ID and its context match as well.
+            The default value is 'any'.
+            In Question Answering, to enforce that the retrieved document is considered correct whenever the answer is correct, set `document_scope` to 'answer' or 'document_id_or_answer'.
     """
     if any(degree > 1 for node, degree in graph.out_degree):
         logger.warning("Pipelines with junctions are currently not supported.")
         return
 
+    answer_nodes = {node for node, df in eval_result.node_results.items() if len(df[df["type"] == "answer"]) > 0}
+    all_top_1_metrics = eval_result.calculate_metrics(
+        document_scope=document_scope, answer_scope=answer_scope, simulated_top_k_reader=1
+    )
+    answer_top_1_metrics = {node: metrics for node, metrics in all_top_1_metrics.items() if node in answer_nodes}
+
     calculated_metrics = {
-        "": eval_result.calculate_metrics(doc_relevance_col=doc_relevance_col),
-        "_top_1": eval_result.calculate_metrics(doc_relevance_col=doc_relevance_col, simulated_top_k_reader=1),
-        " upper bound": eval_result.calculate_metrics(doc_relevance_col=doc_relevance_col, eval_mode="isolated"),
+        "": eval_result.calculate_metrics(document_scope=document_scope, answer_scope=answer_scope),
+        "_top_1": answer_top_1_metrics,
+        " upper bound": eval_result.calculate_metrics(
+            document_scope=document_scope, answer_scope=answer_scope, eval_mode="isolated"
+        ),
     }
 
     if metrics_filter is not None:
@@ -197,7 +245,12 @@ def print_eval_report(
         }
 
     pipeline_overview = _format_pipeline_overview(calculated_metrics=calculated_metrics, graph=graph)
-    wrong_examples_report = _format_wrong_examples_report(eval_result=eval_result, n_wrong_examples=n_wrong_examples)
+    wrong_examples_report = _format_wrong_examples_report(
+        eval_result=eval_result,
+        n_wrong_examples=n_wrong_examples,
+        document_scope=document_scope,
+        answer_scope=answer_scope,
+    )
 
     print(f"{pipeline_overview}\n" f"{wrong_examples_report}")
 
@@ -237,12 +290,23 @@ def _format_wrong_examples_node(node_name: str, wrong_examples_formatted: str):
     return s
 
 
-def _format_wrong_examples_report(eval_result: EvaluationResult, n_wrong_examples: int = 3):
+def _format_wrong_examples_report(
+    eval_result: EvaluationResult,
+    n_wrong_examples: int = 3,
+    document_scope: Literal[
+        "document_id", "context", "document_id_and_context", "document_id_or_context", "answer", "document_id_or_answer"
+    ] = "document_id_or_answer",
+    answer_scope: Literal["any", "context", "document_id", "document_id_and_context"] = "any",
+):
     examples = {
-        node: eval_result.wrong_examples(node, doc_relevance_col="gold_id_or_answer_match", n=n_wrong_examples)
+        node: eval_result.wrong_examples(
+            node, document_scope=document_scope, answer_scope=answer_scope, n=n_wrong_examples
+        )
         for node in eval_result.node_results.keys()
     }
-    examples_formatted = {node: "\n".join(map(_format_wrong_example, examples)) for node, examples in examples.items()}
+    examples_formatted = {
+        node: "\n".join(map(_format_wrong_example, examples)) for node, examples in examples.items() if any(examples)
+    }
 
     return "\n".join(map(_format_wrong_examples_node, examples_formatted.keys(), examples_formatted.values()))
 
