@@ -1,3 +1,4 @@
+from haystack.utils.reflection import args_to_kwargs
 from haystack.utils.preprocessing import convert_files_to_docs, tika_convert_files_to_docs
 from haystack.utils.import_utils import fetch_archive_from_http
 from haystack.utils.cleaning import clean_wiki_text
@@ -9,7 +10,7 @@ from haystack.utils.doc_store import (
     stop_opensearch,
     stop_service,
 )
-from haystack.utils.deepsetcloud import DeepsetCloud, DeepsetCloudError
+from haystack.utils.deepsetcloud import DeepsetCloud, DeepsetCloudError, DeepsetCloudExperiments
 from haystack.utils.export_utils import (
     print_answers,
     print_documents,
